@@ -13,6 +13,7 @@ from encrypt import encrypt_public
 from serialize import serialize_private_key, serialize_public_key
 from deserialize import deserialize_private_key, deserialize_public_key
 from generate import generate_private, generate_public
+from hash import hash_, check_hash
 
-# importing from aes
-from aes import generate_cipher_aes, encrypt_aes, decrypt_aes, load_cipher, serialize_aes, deserialize_aes
+# importing from fernet
+from fernet import *
\ No newline at end of file
